@@ -1,5 +1,5 @@
-import os
-
+import os, sys
+os.system("pip install phonenumbers")
 os.system("clear")
 import os.path
 if os.path.exists("whitelist.txt"):
@@ -8,7 +8,6 @@ else:
   whitelist = open("whitelist.txt", 'x')
   whitelist = open("whitelist.txt", 'r')
 import socket, time, base64
-
 hostname = socket.gethostname()
 IPAddr = socket.gethostbyname(hostname)
 text_bytes = IPAddr.encode('ascii')
