@@ -1,3 +1,12 @@
+import time, sys, random, os
+
+typing_speed = 90 # wpm
+def slowprint(sentence):
+   for char in sentence:
+     sys.stdout.write(char)
+     sys.stdout.flush()
+     time.sleep(random.random()*10.0/typing_speed)
+   print("")  
 def dvd_animation():
   import pygame, time
   pygame.init()
@@ -311,99 +320,8 @@ def pnaclg():
   print("The area code of "+number +" is "+geocoder.description_for_number(ch_nmber, "en"))
   input("Press enter to go back to the script list")
   main()
-def agmt():
-  import os, random
-  print("Ben's Math Test")
-  print("")
-  print('Difficulties:')
-  print("1) Easy")
-  print("2) Normal")
-  print("3) Hard")
-  diffchoice = input(">> ")
-  if diffchoice == '1':
-    os.system("clear")
-    correctanswers = 0
-    wronganswers = 0
-    qstn = 0
-    while qstn < 5:
-      print("")
-      qstn = qstn+1
-      num1 = random.randint(5,15)
-      num2 = random.randint(5,15)
-      num1str = str(num1)
-      num2str = str(num2)
-      print("What is "+num1str+"+"+num2str+"?")
-      answer = input(">> ")
-      correctanswer = num1+num2
-      answer = int(answer)
-      if answer == correctanswer:
-        print("Correct!")
-        correctanswers = correctanswers+1
-      else:
-        print("Incorrect")
-        wronganswers = wronganswers+1
-    correctanswers = str(correctanswers)
-    print("")
-    print("---- QUIZ OVER ----")
-    print("You got "+correctanswers+" out of 5")
-    input("Press enter to go back to the script list")
-    main()
-  if diffchoice == '2':
-    os.system("clear")
-    correctanswers = 0
-    wronganswers = 0
-    qstn = 0
-    while qstn < 5:
-      print("")
-      qstn = qstn+1
-      num1 = random.randint(10,30)
-      num2 = random.randint(10,30)
-      num1str = str(num1)
-      num2str = str(num2)
-      print("What is "+num1str+"+"+num2str+"?")
-      answer = input(">> ")
-      correctanswer = num1+num2
-      answer = int(answer)
-      if answer == correctanswer:
-        print("Correct!")
-        correctanswers = correctanswers+1
-      else:
-        print("Incorrect")
-        wronganswers = wronganswers+1
-    correctanswers = str(correctanswers)
-    print("")
-    print("---- QUIZ OVER ----")
-    print("You got "+correctanswers+" out of 5")
-    input("Press enter to go back to the script list")
-    main()
-  if diffchoice == '3':
-    os.system("clear")
-    correctanswers = 0
-    wronganswers = 0
-    qstn = 0
-    while qstn < 5:
-      print("")
-      qstn = qstn+1
-      num1 = random.randint(4,12)
-      num2 = random.randint(3,9)
-      num1str = str(num1)
-      num2str = str(num2)
-      print("What is "+num1str+"x"+num2str+"?")
-      answer = input(">> ")
-      correctanswer = num1*num2
-      answer = int(answer)
-      if answer == correctanswer:
-        print("Correct!")
-        correctanswers = correctanswers+1
-      else:
-        print("Incorrect")
-        wronganswers = wronganswers+1
-    correctanswers = str(correctanswers)
-    print("")
-    print("---- QUIZ OVER ----")
-    print("You got "+correctanswers+" out of 5")
-    input("Press enter to go back to the script list")
-    main()
+def proxy_site():
+  print("currently unavailable")
 def dwdg():
   import socket
   import re, uuid
@@ -825,7 +743,7 @@ def main():
  print("11)",s11)
  s12 = "piglatin-translator"
  print("12)",s12)
- s13 = "auto-generated-math-test"
+ s13 = "proxy-site"
  print("13)",s13)
  s14 = "dvd-animation"
  print("14)",s14)
@@ -999,7 +917,7 @@ def main():
   print("2) Go back to the script list")
   choice = input(">> ")
   if choice == '1':
-    agmt()
+    proxy_site()
     os.system("")
   elif choice == '2':
     os.system("clear")
